namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Glview::resize_policy_set( ::efl::eolian::in_traits<Elm_GLView_Resize_Policy>::type policy) const
{
   Eina_Bool __return_value =  ::elm_obj_glview_resize_policy_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_GLView_Resize_Policy,  ::efl::eolian::in_traits<Elm_GLView_Resize_Policy>::type>(policy));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Glview::render_policy_set( ::efl::eolian::in_traits<Elm_GLView_Render_Policy>::type policy) const
{
   Eina_Bool __return_value =  ::elm_obj_glview_render_policy_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_GLView_Render_Policy,  ::efl::eolian::in_traits<Elm_GLView_Render_Policy>::type>(policy));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Glview::mode_set( ::efl::eolian::in_traits<Elm_GLView_Mode>::type mode) const
{
   Eina_Bool __return_value =  ::elm_obj_glview_mode_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_GLView_Mode,  ::efl::eolian::in_traits<Elm_GLView_Mode>::type>(mode));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Glview::rotation_get() const
{
   int __return_value =  ::elm_obj_glview_rotation_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Glview::version_constructor( ::efl::eolian::in_traits<Evas_GL_Context_Version>::type version) const
{
    ::elm_obj_glview_version_constructor(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_GL_Context_Version,  ::efl::eolian::in_traits<Evas_GL_Context_Version>::type>(version));
}
inline ::efl::eolian::return_traits<void>::type Glview::draw_request() const
{
    ::elm_obj_glview_draw_request(this->_eo_ptr());
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Glview::resize_policy_set( ::efl::eolian::in_traits<Elm_GLView_Resize_Policy>::type policy) const
{
   Eina_Bool __return_value =  ::elm_obj_glview_resize_policy_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_GLView_Resize_Policy,  ::efl::eolian::in_traits<Elm_GLView_Resize_Policy>::type>(policy));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Glview::render_policy_set( ::efl::eolian::in_traits<Elm_GLView_Render_Policy>::type policy) const
{
   Eina_Bool __return_value =  ::elm_obj_glview_render_policy_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_GLView_Render_Policy,  ::efl::eolian::in_traits<Elm_GLView_Render_Policy>::type>(policy));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Glview::mode_set( ::efl::eolian::in_traits<Elm_GLView_Mode>::type mode) const
{
   Eina_Bool __return_value =  ::elm_obj_glview_mode_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_GLView_Mode,  ::efl::eolian::in_traits<Elm_GLView_Mode>::type>(mode));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Glview::rotation_get() const
{
   int __return_value =  ::elm_obj_glview_rotation_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Glview::version_constructor( ::efl::eolian::in_traits<Evas_GL_Context_Version>::type version) const
{
    ::elm_obj_glview_version_constructor(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_GL_Context_Version,  ::efl::eolian::in_traits<Evas_GL_Context_Version>::type>(version));
}
inline ::efl::eolian::return_traits<void>::type Glview::draw_request() const
{
    ::elm_obj_glview_draw_request(this->_eo_ptr());
}
inline elm::Glview::operator ::elm::Glview() const { return *static_cast< ::elm::Glview const*>(static_cast<void const*>(this)); }
inline elm::Glview::operator ::elm::Glview&() { return *static_cast< ::elm::Glview*>(static_cast<void*>(this)); }
inline elm::Glview::operator ::elm::Glview const&() const { return *static_cast< ::elm::Glview const*>(static_cast<void const*>(this)); }
} }

